#! /usr/bin/python3
#
#################################################################
## Copyright (c) 2013 Norbert S. <junky-zs@gmx.de>
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#
#################################################################
# Ver:A  / Datum 21.01.2014
#################################################################
#
""" Module 'create_databases.py' creats databases 'sqlite' and 'rrdtool'

    All necessary informations are take from xml-configurationfile.
    
    Database 'sqlite' is created if not yet available.
      If available, it will not be overwritten.
    Database 'rrdtool' is only created if the 'enable'-tag in configurationfile
      is set to 'on' or '1'.
      If creation is enabled and the database is already available,
      it will not be overwritten.
"""

import sys, os
sys.path.append('lib')
import db_sqlite
import db_rrdtool

configurationfilename='./etc/config/HT3_db_cfg.xml'
sqlitedb=db_sqlite.cdb_sqlite(configurationfilename)
sqlitedb.connect()
print("------------------------")
print("Create: sqlite -database")
sqlitedb.createdb_sqlite()
#check created sqlite-database for read/write access
databasename=sqlitedb.db_sqlite_filename()
if os.access(databasename,os.W_OK and os.R_OK):
    print("sqlite-database:'{0}' created and access possible".format(databasename))
else:
    print("sqlite-database:'{0}' not available".format(databasename))

sqlitedb.close()

print("------------------------------------------------")
print("Create: rrdtool-database (if request is enabled)")
rrdtool=db_rrdtool.cdb_rrdtool(configurationfilename)
if not rrdtool.is_rrdtool_db_enabled():
    print("rrdtool-database will not be created")
    print("  enable-flag is set to 'False' in configuration")
else:    
    rrdtool.createdb_rrdtool()
    if rrdtool.is_rrdtool_db_available():
        print("rrdtool-databases:'{0}' created and access possible".format(rrdtool.db_rrdtool_filename()))
    else:
        print("rrdtool-databases:'{0}' not available".format(rrdtool.db_rrdtool_filename()))
