#!/usr/bin/perl
#
use strict;
use warnings;
use RRDTool::OO;
use File::Spec;


my $mypath       =$ARGV[0];
my $mystart_param=$ARGV[1];
my $myend_param  =$ARGV[2];

my $rc = 0;
my $DB_heizgeraet   = File::Spec->catfile($mypath,"/HT3/software/var/databases/HT3_db_rrd_heizgeraet.rrd");
my $heizgeraet_rrdh = RRDTool::OO->new(file => $DB_heizgeraet);
my $DB_heizkreis    = File::Spec->catfile($mypath,"/HT3/software/var/databases/HT3_db_rrd_heizkreis.rrd");
my $heizkreis_rrdh  = RRDTool::OO->new(file => $DB_heizkreis);
my $DB_warmwasser   = File::Spec->catfile($mypath,"/HT3/software/var/databases/HT3_db_rrd_warmwasser.rrd");
my $warmwasser_rrdh = RRDTool::OO->new(file => $DB_warmwasser);
my $DB_solar        = File::Spec->catfile($mypath,"/HT3/software/var/databases/HT3_db_rrd_solar.rrd");
my $solar_rrdh      = RRDTool::OO->new(file => $DB_solar);
# 
# Set Starttime
my $start_time     = time()-2880*60;
my $end_time       = time();

if ( defined $mystart_param && defined $myend_param ){
	if ($mystart_param < $myend_param) {
		$start_time = $mystart_param;
		$end_time   = $myend_param;
	} else {
		$start_time = $myend_param;
		$end_time   = $mystart_param;
	}
} else {
	if (defined $mystart_param) {
		$start_time = $mystart_param;
	}
}

## only for test activated
#  $start_time     = 1391981429;
#  $end_time       = 1392047789;

### generate timestring for title
my ($vonsek, $vonmin, $vonhour, $vonday, $vonmon, $vonyear)=localtime($start_time);
my ($bissek, $bismin, $bishour, $bisday, $bismon, $bisyear)=localtime($end_time);
my $timeendstring=sprintf(" - %02d:%02d:%02d %02d.%02d.%04d)",$bishour,$bismin,$bissek,$bisday,$bismon+1,$bisyear+1900);
my $timestring   =sprintf(" (%02d:%02d:%02d %02d.%02d.",$vonhour,$vonmin,$vonsek,$vonday,$vonmon+1).$timeendstring;

# Anzeige gross/klein
my $AnzeigeGross	= 1;
my $mywidth		= 350;
my $myheight		= 160;
if ($AnzeigeGross == 1) {
	$mywidth	= 740;
	$myheight	= 310;
}

my $ImageHG       ="/tmp/HT3_Heizgeraet.png";
my $ImageHK       ="/tmp/HT3_Heizkreis.png";
my $ImageWW       ="/tmp/HT3_Warmwasser.png";
my $ImageSO       ="/tmp/HT3_Solar.png";
my $ImageSO_ertrag="/tmp/HT3_Solarertrag.png";

$rc = $heizgeraet_rrdh->graph(
	image			=> $ImageHG,
	vertical_label	=> 'Temperaturen (Celsius)',
	start			=> $start_time,
	end				=> $end_time,
	width			=> $mywidth,
	height			=> $myheight,
	title			=> 'Heizgerät'.$timestring,
	color			=> { back => '#ffdd55',
						canvas => '#fff6d5',
	},
	# Background draw fuer betriebsmodus:='heizung'
	draw		=> {
		dsname	=> 'V_modus',
		color	=> '0cccc0',
		type	=> 'hidden',
		name	=> 'modusfkt',
	},
	draw		=> {
		color	=> 'e9ddaf',
		type	=> 'area',
		cdef	=> "modusfkt,90,*"
	},
	draw		=> {
		dsname	=> 'V_leistung',
		legend	=> 'Brennerleistung (%)\l',
		color	=> 'cccccc',
		type	=> 'area'
	},
	draw		=> {
		dsname	=> 'T_vorlauf_soll',
		legend	=> 'Vorlauf soll\l',
		color	=> 'ff0000'
	},
	draw		=> {
		dsname	=> 'T_vorlauf_ist',
		legend	=> 'Vorlauf ist\l',
		thickness => 1,
		color	=> '0000ff'
	},
	draw		=> {
		dsname	=> 'T_ruecklauf',
		legend	=> 'Rücklauf\l',
		thickness => 1,
		color	=> '00ff00'
	},
#	draw           => {
#		dsname => 'T_mischer',
#		legend => 'Mischer',
#		color  => '800080'
#	},
	comment		=> ' \s',
	comment		=> ' \s',
	comment		=> ' \s',
	comment		=> ' \s',
);

$rc = $heizkreis_rrdh->graph(
	image			=> $ImageHK,
	vertical_label	=> 'Temperaturen (Celsius)',
	start			=> $start_time,
	end				=> $end_time,
	width			=> $mywidth,
	height			=> $myheight,
	title			=> 'Heizkreis'.$timestring,
	color			=> {back => '#ffeeaa',
						canvas => '#fff6d5',
	},
	draw		=> {
		dsname	=> 'T_soll_HK1',
		legend	=> 'HK(1) Soll\l',
		color	=> 'ff0000'
	},
	draw		=> {
		dsname	=> 'T_ist_HK1',
		legend	=> 'HK(1) Ist\l',
		color	=> '00ff00'
	},
	draw		=> {
		dsname	=> 'T_steuer_FB',
		name	=> 'Raumtemperatur',
		legend	=> 'Raumtemperatur   min\:',
		thickness => 2,
		color	=> '8080ff'
	},
	# vdef for calculating Maximum, Minimum of 'Raumtemperatur'
	draw		=> {
		type	=> "hidden",
		name	=> "Raumtemperatur_min",
	vdef	=> "Raumtemperatur,MINIMUM",
	},
	gprint		=> {
		format	=> '%3.2lf',
		draw	=> 'Raumtemperatur_min',
	},
	draw		=> {
		type	=> "hidden",
		name	=> "Raumtemperatur_max",
		vdef	=> "Raumtemperatur,MAXIMUM",
	},
	comment		=> 'max\:',
	gprint		=> {
		format	=> '%3.2lf\l',
		draw	=> 'Raumtemperatur_max',
	},

	draw		=> {
		dsname	=> 'T_aussen',
		name	=> 'Aussentemperatur',
		legend	=> 'Aussentemperatur min\:',
		thickness => 2,
		color	=> '000055'
	},
	# vdef for calculating Maximum, Minimum of 'Aussentemperatur'
	draw		=> {
		type	=> "hidden",
		name	=> "Aussentemperatur_min",
		vdef	=> "Aussentemperatur,MINIMUM",
	},
	gprint		=> {
		format	=> '%3.2lf',
		draw	=> 'Aussentemperatur_min',
	},
	draw		=> {
		type	=> "hidden",
		name	=> "Aussentemperatur_max",
		vdef	=> "Aussentemperatur,MAXIMUM",
	},
	comment		=> 'max\:',
	gprint		=> {
		format	=> '%3.2lf\l',
		draw	=> 'Aussentemperatur_max',
	},

	draw		=> {
		dsname	=> 'C_betrieb_gesamt',
		name	=> 'BZeitg',
		type	=> "hidden",
		cfunc	=> 'LAST'
	},
	draw		=> {
		type	=> "hidden",
		name	=> "BZeitg_average",
		vdef	=> "BZeitg,LAST",
	},
	gprint		=> {
		format	=> '  Betriebszeit gesamt \: %6.lf Minuten\l',
		draw	=> 'BZeitg_average',
	},

	draw		=> {
		dsname	=> 'C_brenner_heizung',
		name	=> 'brennereinheiz',
		type	=> "hidden",
		cfunc	=> 'LAST'
	},
	draw		=> {
		type	=> "hidden",
		name	=> "brennereinheiz_last",
		vdef	=> "brennereinheiz,LAST",
	},
	gprint		=> {
		format	=> '  Brenner ein         \: %6.lf Zähler',
		draw	=> 'brennereinheiz_last',
	},
);

$rc = $warmwasser_rrdh->graph(
	image			=> $ImageWW,
	vertical_label	=> 'Temperaturen (Celsius)',
	start			=> $start_time,
	end				=> $end_time,
	width			=> $mywidth,
	height			=> $myheight,
	title			=> 'Warmwasser'.$timestring,
	color			=> {back => '#aaccff',
						canvas => '#d5e5ff',
	},
	draw		=> {
		dsname	=> 'T_soll',
		legend	=> 'Soll\l',
		color	=> 'ff0000'
	},
	draw		=> {
		dsname	=> 'T_ist',
		legend	=> 'Ist (Mischer)\l',
		color	=> '0000ff'
	},
	draw		=> {
		dsname	=> 'T_speicher',
		legend	=> 'Speicher min\:',
		name	=> 'Speicher',
		thickness => 2,
		color	=> '00ff00'
	},
	# vdef for calculating Maximum, Minimum of 'Speicher'
	draw		=> {
		type	=> "hidden",
		name	=> "Speicher_min",
		vdef	=> "Speicher,MINIMUM",
	},
	gprint		=> {
		format	=> '%3.2lf',
	draw	=> 'Speicher_min',
	},
	draw		=> {
		type	=> "hidden",
		name	=> "Speicher_max",
		vdef	=> "Speicher,MAXIMUM",
	},
	gprint		=> {
		format	=> 'max\:%3.2lf\l',
		draw	=> 'Speicher_max',
	},
	draw		=> {
		dsname	=> 'C_betriebs_zeit',
		name	=> 'BZeit',
		type	=> "hidden",
	},
	draw		=> {
		type	=> "hidden",
		name	=> "BZeit_average",
		vdef	=> "BZeit,AVERAGE",
	},
	gprint		=> {
		format	=> '  Betriebszeit\:%5.lf Minuten',
		draw	=> 'BZeit_average',
	},
);
$rc = $solar_rrdh->graph(
	image			=> $ImageSO,
	vertical_label	=> 'Temperaturen (Celsius)',
	start			=> $start_time,
	end				=> $end_time,
	width			=> $mywidth,
	height			=> $myheight,
	color			=> {	back => '#c6e9af',
			    			canvas => '#e3f4d7',
	},
	title	=> 'Solar'.$timestring,
	##### Speicher unten #####
	draw		=> {
		dsname	=> 'T_speicher_unten',
		legend	=> 'Solarspeicher unten',
		thickness => 1,
		color	=> '00ff88',
		type	=> 'area',
		name	=> 'speiunten',
	},
	# vdef for calculating Maximum, Minimum of 'Speicher unten'
	draw		=> {
		type	=> "hidden",
		name	=> "speiunten_min",
		vdef	=> "speiunten,MINIMUM",
	},
	gprint		=> {
		format	=> 'min\:%3.2lf',
		draw	=> 'speiunten_min',
	},
	draw		=> {
		type	=> "hidden",
		name	=> "speiunten_max",
		vdef	=> "speiunten,MAXIMUM",
	},
	gprint		=> {
		format	=> 'max\:%3.2lf\l',
		draw	=> 'speiunten_max',
	},
	comment	=>	'\j',
	##### Kollektor #####
	draw	=> {
		dsname	=> 'T_kollektor',
		color	=> 'cccc00',
		type	=> 'area',
		name	=> 'kollektor'  # name fuer den hidden draw
	},
	draw		=> {
		dsname	=> 'T_kollektor',
		legend	=> 'Kollektor          ',
		thickness => 1,
		color	=> 'ffcc00',
		cfunc	=> 'AVERAGE'
	},
	# vdef for calculating Maximum, Minimum of 'Kollektor'
	draw		=> {
		type	=> "hidden",
		name	=> "kollektor_min",
		vdef	=> "kollektor,MINIMUM",
	},
	gprint		=> {
		format	=> 'min\:%03.2lf',
		draw	=> 'kollektor_min',
	},
	draw		=> {
		type	=> "hidden",
		name	=> "kollektor_max",
		vdef	=> "kollektor,MAXIMUM",
	},
	gprint		=> {
		format	=> 'max\:%03.2lf\l',
		draw	=> 'kollektor_max',
	},

	draw		=> {
		dsname	=> 'T_speicher_unten',
		thickness => 1,
		color	=> '00ffcc',
	},

	##### Solarpumpe #####
	draw		=> {
		dsname	=> 'V_solar_pumpe',
		type	=> "hidden",
		name	=> 'solpumpe'  # name fuer den hidden draw
	},
	draw		=> {
		color	=> 'ff6600',
		legend	=> 'Solarpumpe an\l',
		type	=> 'area',
		cdef	=> "solpumpe,5,*"
	},
	comment		=> ' \s',
	comment		=> ' \s',

);

$rc = $solar_rrdh->graph(
	image			=> $ImageSO_ertrag,
	vertical_label	=> '(k)Wh',
	start			=> $start_time,
	end				=> $end_time,
	width			=> $mywidth,
	height			=> $myheight,
	color			=>	{	back => '#c6e9af',
							canvas => '#e3f4d7',
						},
	title		=> 'Solar Ertrag'.$timestring,

	##### Ertrag pro Stunde #####
	draw		=> {
		dsname	=> 'V_ertrag_stunde',
		legend	=> 'Ertrag/Stunde  max\:',
		color	=> 'aa88f0',
		type	=> 'area'
	},
	draw		=> {
		dsname	=> 'V_ertrag_stunde',
		color	=> 'aa8800',
		thickness => 2,
		name	=> 'ertrag_std',
	},
	draw		=> {
		type	=> "hidden",
		name	=> "ertrag_draw",
		vdef	=> "ertrag_std,MAXIMUM",
	},
	gprint		=> {
		format	=> '%6.2lf %SWh\l',
		draw	=> 'ertrag_draw',
	},

	##### Solarpumpen-Laufzeit #####
	draw		=> {
		dsname	=> 'C_laufzeit',
		name	=> 'pumpenlaufzeit',
		type	=> "hidden",
	},
	draw		=> {
		type	=> "hidden",
		name	=> "pumpenlauf_draw",
		vdef	=> "pumpenlaufzeit,LAST",
#		cdef	=> "pumpenlaufzeit,0.017,*",
	},
	gprint		=> {
		format	=> '  Laufzeit Pumpe    \:%5.0lf Minuten',
		draw	=> 'pumpenlauf_draw',
	},
);


