#! /usr/bin/python3
#
#################################################################
## Copyright (c) 2013 Norbert S. <junky-zs@gmx.de>
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#
#################################################################
# Ver:A  / Datum 21.01.2014
#################################################################
#
""" Class 'gui_cworker' for creating HT3 - Graphical User Interface (GUI)

gui_cworker.__init__    -- constructor of class 'gui_cworker'. this will main-object to tkinter.Tk and frames
                             mandatory: parameter 'gdata' as handle to cdata object
                             optional : hexdump_window  (default is value 'True')
run                     -- main loop to start GUI endless
                             mandatory: none
                             
"""

import sys, tkinter, time
import _thread
import data

class gui_cworker(object):
    def __init__(self, gdata, hexdump_window=True):
        try:
            if not isinstance(gdata, data.cdata):
                raise TypeError("gdata")
            if not (isinstance(hexdump_window, int) or isinstance(hexdump_window, bool)):
                raise TypeError("hexdump_window")
            self.__gdata  = gdata
            self.__current_display="system"
            self.__hexdump_window =hexdump_window
            self.__threadrun=True

            self.__main = tkinter.Tk()

            # Frame 1,2,3 with Buttons 
            self.__fr1 = tkinter.Frame(self.__main, relief="sunken", bd=5)
            self.__fr1.pack(side="top")
            if self.__hexdump_window :
                self.__main.title('Heatronic3 Analyser (Rev:A)')
                self.__main.geometry("1000x800+330+230")
                self.__fr2 = tkinter.Frame(self.__fr1, relief="sunken", bd=2)
                self.__fr2.pack(side="left")
            else:
                self.__main.title('Heatronic3 Systemstatus (Rev:A)')
                self.__main.geometry("550x750+330+230")
                self.__fr2 = None
                
            self.__fr3 = tkinter.Frame(self.__fr1, relief="sunken", bd=3)
            self.__fr3.pack(side="right")

            if self.__hexdump_window :
                self.__bhexdclear = tkinter.Button(self.__fr2, text="Hexdump clear",
                                                highlightbackground="red",
                                                command = self.__hexclear)
                self.__bhexdclear.pack(padx=5, pady=5, side="left")
                
                self.__bende = tkinter.Button(self.__fr2, text = "Ende",
                                            highlightbackground="black",
                                            command = self.__ende)
                self.__bende.pack(padx=5, pady=5, side="right")
            else:
                self.__bende = tkinter.Button(self.__fr3, text = "Ende",
                                            highlightbackground="black",
                                            command = self.__ende)
                self.__bende.pack(padx=5, pady=5, side="right")
                
            self.__bsys = tkinter.Button(self.__fr3, text="System",
                                         highlightbackground="yellow",
                                         command = self.__system_button)
            self.__bsys.pack(padx=5, pady=5, side="left")
            self.__bhge = tkinter.Button(self.__fr3, text="Heizgeraet",
                                         highlightbackground="orange",
                                         command = self.__Heizgeraet_button)
            self.__bhge.pack(padx=5, pady=5, side="left")
            self.__bhkr = tkinter.Button(self.__fr3,text="Heizkreis",
                                         highlightbackground="moccasin",
                                         command = self.__Heizkreis_button)
            self.__bhkr.pack(padx=5, pady=5, side="left")
            self.__bwwa = tkinter.Button(self.__fr3, text="Warmwasser",
                                         highlightbackground="lightblue",
                                         command = self.__Warmwasser_button)
            self.__bwwa.pack(padx=5, pady=5, side="left")
            self.__bsola = tkinter.Button(self.__fr3, text="Solar",
                                         highlightbackground="lightgreen",
                                          command = self.__Solar_button)
            self.__bsola.pack(padx=5, pady=5, side="left")

            if self.__hexdump_window :
                #frame for hexdump
                self.__hexdumpfr = tkinter.Frame(self.__main, width=1000, relief="sunken", bd=1)
                self.__hexdumpfr.pack(side="left", expand=1, fill="both")
                self.__hextext = tkinter.Text(self.__hexdumpfr)
                self.__hextext.pack(side="left", expand=1, fill="both")
                self.__colourconfig(self.__hextext)
                self.__Hextext_bytecomment()

            #frame for data
            self.__datafr = tkinter.Frame(self.__main, width=1, relief="sunken", bd=4)
            self.__datafr.pack(side="left", fill="both")
            self.__text = tkinter.Text(self.__datafr)
            self.__text.pack(side="left", expand=1, fill="both")
            self.__colourconfig(self.__text)
        
        except (TypeError) as e:
            print('gui_cworker();Error;Parameter:<{0}> has wrong type'.format(e.args[0]))
            raise TypeError
        
    def __del__(self):
        pass

    def run(self):
        # start thread for updating display
        _thread.start_new_thread(self.__anzeigethread, (0,))
        # run endless
        while self.__threadrun:
            self.__main.mainloop()
        return False

    def __anzeigethread(self, parameter):
        while self.__threadrun:
            self.__anzeigesteuerung()
            if self.__threadrun:
                time.sleep(1)
            else:
                break
            
    def __ende(self):
        self.__threadrun=False
        self.__main.destroy()

    def __Lokalezeit(self):
        self.__text.insert("end", "                                 \n","u")
        self.__text.insert("end", "Aktuelles Datum / Zeit           \n","u")
        datum='        Datum: ' + time.strftime("%d.%m.%Y")+'\n'
        zeit ='        Zeit : ' + time.strftime("%H:%M:%S")+'\n'
        self.__text.insert("end", datum)
        self.__text.insert("end", zeit)

    def __system_button(self):
        self.__current_display="system"
        self.__clear()
        self.__Lokalezeit()
        self.__System()

        
    def __System(self):
        self.__text.insert("end", "Systemstatus Junkers Heatronic3  \n","b_ye")
        self.__Info()
        self.__Heizgeraet()
        self.__Heizkreis()
        self.__Warmwasser()
        self.__Solar()
        self.__text.insert("end", "                                 \n","u")

    def __Info(self):
        nickname="DT"
        self.__text.insert("end", "System-Infos                     \n","b_gray")
        datum  =' System-Datum: ' + str(self.__gdata.values(nickname,"Date"))+'\n'
        self.__text.insert("end", datum)
        uhrzeit=' System-Zeit : ' + str(self.__gdata.values(nickname,"Time"))+'\n'
        self.__text.insert("end", uhrzeit)
        if (self.__gdata.IsSyspartUpdate(nickname) and self.__hexdump_window):
            temptext=self.__gdata.values(nickname,"hexdump")
            temptext+="\n"
            self.__hextext.insert("end",temptext,"b_gray")

    def __Heizgeraet_button(self):
        nickname="HG"
        # dummy-read to clear flag
        self.__gdata.IsSyspartUpdate(nickname)
        self.__current_display=str(self.__gdata.getlongname(nickname))
        self.__clear()
        self.__Lokalezeit()
        self.__Heizgeraet()

    def __Heizgeraet(self):
        nickname="HG"
        self.__text.insert("end", "Heizgeraet                       \n","b_or")
        temptext=" T-Vorlauf Soll       : "+format(int(self.__gdata.values(nickname,"Tvorlauf_soll")),"2d")+'   Grad\n'
        self.__text.insert("end",temptext)
        temptext=" T-Vorlauf ist        : "+format(float(self.__gdata.values(nickname,"Tvorlauf_ist")),".1f")+' Grad\n'
        self.__text.insert("end",temptext)
        temptext=" T-Ruecklauf          : "+format(float(self.__gdata.values(nickname,"Truecklauf")),".1f")+' Grad\n'
        self.__text.insert("end",temptext)
        temptext=" T-Mischer            : "+format(float(self.__gdata.values(nickname,"Tmischer")),".1f")+' Grad\n'
        self.__text.insert("end",temptext)
        temptext=" Betriebsmodus        : "+self.__GetStrBetriebsmodus(self.__gdata.values(nickname,"Vmodus"))+' (Heizen/Warmwasser)\n'
        self.__text.insert("end",temptext)
        temptext=" Brennermotor         : "+self.__GetStrOnOff(self.__gdata.values(nickname,"Vbrenner_motor"))+'\n'
        self.__text.insert("end",temptext)
        temptext=" Brennerflamme        : "+self.__GetStrOnOff(self.__gdata.values(nickname,"Vbrenner_flamme"))+'\n'
        self.__text.insert("end",temptext)
        temptext=" Leistung             : "+format(int(self.__gdata.values(nickname,"Vleistung")),"d")+'    %\n'
        self.__text.insert("end",temptext)
        temptext=" Heizungspumpe        : "+self.__GetStrOnOff(self.__gdata.values(nickname,"Vheizungs_pumpe"))+'\n'
        self.__text.insert("end",temptext)
        temptext=" Zirkulationspumpe    : "+self.__GetStrOnOff(self.__gdata.values(nickname,"Vzirkula_pumpe"))+'\n'
        self.__text.insert("end",temptext)
        temptext=" Speicherladepumpe    : "+self.__GetStrOnOff(self.__gdata.values(nickname,"Vspeicher_pumpe"))+'\n'
        self.__text.insert("end",temptext)

        if (self.__gdata.IsSyspartUpdate(nickname) and self.__hexdump_window):
            temptext=self.__gdata.values(nickname,"hexdump")
            temptext+="\n"
            self.__hextext.insert("end",temptext,"b_or")

        
        if self.__current_display==str(self.__gdata.getlongname(nickname)):
            self.__text.insert("end","\n")
            self.__text.insert("end","Byte-Nr  Wert(hex)      Bedeutung         \n","b_gray")
            self.__text.insert("end"," 00-03   88 00 18 00    Telegram-Kennung \n")
            self.__text.insert("end"," 04      xy             T-Vorlauf Soll \n")
            self.__text.insert("end"," 05      Hi-Byte        T-Vorlauf Ist\n")
            self.__text.insert("end"," 06      Lo-Byte        T-Vorlauf Ist\n")
            self.__text.insert("end"," 07      5x/<>5x        Betriebsmodus: Heizen/Warmwasser\n")
            self.__text.insert("end"," 08      xy             Brennerleistung\n")
            self.__text.insert("end"," 09      Bitfeld        87654321 BitNr \n")
            self.__text.insert("end","                        8765 3     Immer 0\n")
            self.__text.insert("end","                            4      Brennerflamme an\n")
            self.__text.insert("end","                              2    Warmwasser-Mode\n")
            self.__text.insert("end","                               1   Heizungs  -Mode\n")
            self.__text.insert("end","         00|01|02   |09|0A    (Werte mit Byte10)\n")
            self.__text.insert("end"," 10      02|03|02,03|03|02,03\n")
            self.__text.insert("end"," 11      Bitfeld        87654321 BitNr\n")
            self.__text.insert("end","                        8          Zirkulationspumpe WW\n")
            self.__text.insert("end","                         7         Speicherladepumpe WW\n")
            self.__text.insert("end","                          6        Heizungspumpe\n")
            self.__text.insert("end","                           5  2    Immer 0\n")
            self.__text.insert("end","                            4      Zuendung des Brenner\n")
            self.__text.insert("end","                             3 1   Brenner an mit Vor-Nachlauf\n")
            self.__text.insert("end"," 12      c0             \n")
            self.__text.insert("end"," 13      Hi-Byte        T-Mischer\n")
            self.__text.insert("end"," 14      Lo-Byte        T-Mischer\n")
            self.__text.insert("end"," 15-16   80/00          ?\n")
            self.__text.insert("end"," 17      Hi-Byte        T-Ruecklauf\n")
            self.__text.insert("end"," 18      Lo-Byte        T-Ruecklauf\n")
            self.__text.insert("end"," 19-28   xy             ?\n")
            self.__text.insert("end"," 29      xy             CRC Wert\n")
            self.__text.insert("end"," 30      00             Break-Flag\n")


    def __Heizkreis_button(self):
        nickname="HK"
        # dummy-read to clear flag
        self.__gdata.IsSyspartUpdate(nickname)
        self.__current_display=str(self.__gdata.getlongname(nickname))
        self.__clear()
        self.__Lokalezeit()
        self.__Heizkreis()

    def __Heizkreis(self):
        nickname="HK"
        self.__text.insert("end", "Heizkreis                        \n","b_mocca")
        temptext=" T-Aussen             : "+format(float(self.__gdata.values(nickname,"Taussen")),".1f")+' Grad\n'
        self.__text.insert("end",temptext)
        temptext=" T-Soll Heizkreis 1   : "+format(float(self.__gdata.values(nickname,"Tsoll_HK1")),".1f")+' Grad\n'
        self.__text.insert("end",temptext)
        temptext=" T-Ist  Heizkreis 1   : "+format(float(self.__gdata.values(nickname,"Tist_HK1")),".1f")+' Grad\n'
        self.__text.insert("end",temptext)
        temptext=" T-Steuer Fernbedien. : "+format(float(self.__gdata.values(nickname,"Tsteuer_FB")),".1f")+' Grad\n'
        self.__text.insert("end",temptext)
        betrieb_gesamt_ein=int(self.__gdata.values(nickname,"Cbetrieb_gesamt"))
        temptext=" Betrieb Gesamt       : "+format(betrieb_gesamt_ein,"d")+' Minuten := '+ \
                      format(int(betrieb_gesamt_ein/60),".0f")+' Stunden\n'
        self.__text.insert("end",temptext)
        betrieb_heizung_ein=int(self.__gdata.values(nickname,"Cbetrieb_heizung"))
        temptext=" Betrieb Heizung      : "+format(betrieb_heizung_ein,"d")+' Minuten := '+ \
                      format(int(betrieb_heizung_ein/60),".0f")+' Stunden\n'
        self.__text.insert("end",temptext)
        temptext=" Brenner Gesamt  Ein  : "+format(int(self.__gdata.values(nickname,"Cbrenner_gesamt")),"d")+' Zaehler\n'
        self.__text.insert("end",temptext)
        temptext=" Brenner Heizung Ein  : "+format(int(self.__gdata.values(nickname,"Cbrenner_heizung")),"d")+' Zaehler\n'
        self.__text.insert("end",temptext)
        temptext=" Betriebsart          : "+self.__GetStrBetriebsart(self.__gdata.values(nickname,"Vbetriebs_art"))+' (Heizen/Sparen/Frost)\n'
        self.__text.insert("end",temptext)

        if (self.__gdata.IsSyspartUpdate(nickname) and self.__hexdump_window):
            temptext=self.__gdata.values(nickname,"hexdump")
            temptext+="\n"
            self.__hextext.insert("end",temptext,"b_mocca")

        if self.__current_display==str(self.__gdata.getlongname(nickname)):
            self.__text.insert("end","\n")
            self.__text.insert("end","Byte-Nr  Wert(hex)      Bedeutung         \n","b_gray")
            self.__text.insert("end"," 00-03   88 00 19 00    Telegram-Kennung \n")
            self.__text.insert("end"," 04      Hi-Byte        T-Aussen\n")
            self.__text.insert("end"," 05      Lo-Byte        T-Aussen\n")
            self.__text.insert("end"," 06-13   8 Byte         Immer 80 00 80 00 ff ff 00 41\n")
            self.__text.insert("end"," 14-16   B3 B2 B1       Brenner Gesamt Ein  (Zaehler)\n")
            self.__text.insert("end"," 17-19   B3 B2 B1       Betrieb Gesamt      (Minuten)\n")
            self.__text.insert("end"," 20-22   3 Byte         Immer 0\n")
            self.__text.insert("end"," 23-25   B3 B2 B1       Betrieb Heizung     (Minuten)\n")
            self.__text.insert("end"," 26-28   B3 B2 B1       Brenner Heizung Ein (Zaehler)\n")
            self.__text.insert("end"," 29-30   2 Byte         Immer 80 00\n")
            self.__text.insert("end"," 31      xy             CRC\n")
            self.__text.insert("end"," 32      00             Break-Flag\n")

            self.__text.insert("end","\n")
            self.__text.insert("end","Byte-Nr  Wert(hex)      Bedeutung         \n","b_gray")
            self.__text.insert("end"," 00-03   90 00 ff 00    Telegram-Kennung \n")
            self.__text.insert("end"," 04      Bitfeld        Meistens 0\n")
            self.__text.insert("end"," 05      Bitfeld        Meistens 6f/70 (Heizkreis 1/2)\n")
            self.__text.insert("end"," 06      01/02/03       Betriebsart (Frost/Sparen/Heizen)\n")
            self.__text.insert("end"," 07      xy             ?\n")
            self.__text.insert("end"," 08      Hi-Byte        T-Soll Heizkreis 1\n")
            self.__text.insert("end"," 09      Lo-Byte        T-Soll Heizkreis 1\n")
            self.__text.insert("end"," 10      Hi-Byte        T-Ist  Heizkreis 1\n")
            self.__text.insert("end"," 11      Lo-Byte        T-Ist  Heizkreis 1\n")
            self.__text.insert("end"," 12      Hi-Byte        T-Fernbedienung\n")
            self.__text.insert("end"," 13      Lo-Byte        T-Fernbedienung\n")
            self.__text.insert("end"," 14      Bitfeld        Meistens 0\n")
            self.__text.insert("end"," 15      xy             CRC\n")
            self.__text.insert("end"," 16      00             Break-Flag\n")

    def __Warmwasser_button(self):
        nickname="WW"
        # dummy-read to clear flag
        self.__gdata.IsSyspartUpdate(nickname)
        self.__current_display=str(self.__gdata.getlongname(nickname))
        self.__clear()
        self.__Lokalezeit()
        self.__Warmwasser()

    def __Warmwasser(self):
        nickname="WW"
                
        self.__text.insert("end", "Warmwasser                       \n","b_bl")
        temptext=" T-Soll               : "+format(int(self.__gdata.values(nickname,"Tsoll")),"2d")+'   Grad\n'
        self.__text.insert("end",temptext)
        temptext=" T-Ist (Mischer)      : "+format(float(self.__gdata.values(nickname,"Tist")),".1f")+' Grad\n'
        self.__text.insert("end",temptext)
        temptext=" T-Speicher           : "+format(float(self.__gdata.values(nickname,"Tspeicher")),".1f")+' Grad\n'
        self.__text.insert("end",temptext)
        betriebszeit=int(self.__gdata.values(nickname,"Cbetriebs_zeit"))
        temptext=" Betriebszeit         : "+format(betriebszeit,"d")+' Minuten := '+ \
                      format(int(betriebszeit/60),".0f")+' Stunden\n'
        self.__text.insert("end",temptext)
        
        if (self.__gdata.IsSyspartUpdate(nickname) and self.__hexdump_window):
            temptext=self.__gdata.values(nickname,"hexdump")
            temptext+="\n"
            self.__hextext.insert("end",temptext,"b_bl")
            
        if self.__current_display==str(self.__gdata.getlongname(nickname)):
            self.__text.insert("end","\n")
            self.__text.insert("end","Byte-Nr  Wert(hex)      Bedeutung         \n","b_gray")
            self.__text.insert("end"," 00-03   88 00 34 00    Telegram-Kennung \n")
            self.__text.insert("end"," 04      xy             T-Soll\n")
            self.__text.insert("end"," 05      Hi-Byte        T-Ist (Mischer)\n")
            self.__text.insert("end"," 06      Lo-Byte        T-Ist (Mischer)\n")
            self.__text.insert("end"," 07      Hi-Byte        T-Speicher\n")
            self.__text.insert("end"," 08      Lo-Byte        T-Speicher\n")
            self.__text.insert("end"," 09-13   xy             ?\n")
            self.__text.insert("end"," 14-16   B3 B2 B1       Betriebszeit (Minuten)\n")
            self.__text.insert("end"," 17-20   xy             ?\n")
            self.__text.insert("end"," 21      xy             CRC\n")
            self.__text.insert("end"," 22      00             Break-Flag\n")

    def __Solar_button(self):
        nickname="SO"
        # dummy-read to clear flag
        self.__gdata.IsSyspartUpdate(nickname)
        self.__current_display=str(self.__gdata.getlongname(nickname))
        self.__clear()
        self.__Lokalezeit()
        self.__Solar()

    def __Solar(self):
        nickname="SO"
        
        self.__text.insert("end", "Solar                            \n","b_gr")
        temptext=" T-Kollektor          : "+format(float(self.__gdata.values(nickname,"Tkollektor")),".1f")+' Grad\n'
        self.__text.insert("end",temptext)
        temptext=" T-Speicher unten     : "+format(float(self.__gdata.values(nickname,"Tspeicher_unten")),".1f")+' Grad\n'
        self.__text.insert("end",temptext)
        temptext=" Ertrag letzte Stunde : "+format(int(self.__gdata.values(nickname,"V_ertrag_stunde")),"d")+' Wh\n'
        self.__text.insert("end",temptext)
        temptext=" Ertrag Wert 2        : "+format(int(self.__gdata.values(nickname,"V_ertrag_2")),"d")+'\n'
        self.__text.insert("end",temptext)
        laufzeit_minuten=int(self.__gdata.values(nickname,"Claufzeit"))
        temptext=" Laufzeit             : "+format(laufzeit_minuten,"d")+' Minuten := '+ \
                      format(int(laufzeit_minuten/60),".0f")+' Stunden\n'
        self.__text.insert("end",temptext)
        temptext=" Solarpumpe           : "+self.__GetStrOnOff(self.__gdata.values(nickname,"Vsolar_pumpe"))+'\n'
        self.__text.insert("end",temptext)

        if (self.__gdata.IsSyspartUpdate(nickname) and self.__hexdump_window):
            temptext=self.__gdata.values(nickname,"hexdump")
            temptext+="\n"
            self.__hextext.insert("end",temptext,"b_gr")
            
        if self.__current_display==str(self.__gdata.getlongname(nickname)):
            self.__text.insert("end","\n")
            self.__text.insert("end","Byte-Nr  Wert(hex)      Bedeutung \n","b_gray")
            self.__text.insert("end"," 00-03   b0 00 ff 00    Telegram-Kennung \n")
            self.__text.insert("end"," 04      00             ? \n")
            self.__text.insert("end"," 05      03             ? Solarkreis\n")
            self.__text.insert("end"," 06      Hi-Byte        Ertrag Wert2 ? \n")
            self.__text.insert("end"," 07      Lo-Byte        Ertrag Wert2 ? \n")
            self.__text.insert("end"," 08      Hi-Byte        Ertrag letzte Stunde \n")
            self.__text.insert("end"," 09      Lo-Byte        Ertrag letzte Stunde\n")
            self.__text.insert("end"," 10      Hi-Byte        T-Kollektor      \n")
            self.__text.insert("end"," 11      Lo-Byte        T-Kollektor      \n")
            self.__text.insert("end"," 12      Hi-Byte        T-Speicher unten \n")
            self.__text.insert("end"," 13      Lo-Byte        T-Speicher unten \n")
            self.__text.insert("end"," 14      Bitfeld        Solarpumpe 00/01:=aus/ein\n")
            self.__text.insert("end"," 15-16   00/00          ?\n")
            self.__text.insert("end"," 17      Hi-Byte        Laufzeit Solarpumpe (Minuten)\n")
            self.__text.insert("end"," 18      Lo-Byte        Laufzeit Solarpumpe (Minuten)\n")
            self.__text.insert("end"," 19      xy             CRC Wert\n")
            self.__text.insert("end"," 20      00             Break-Flag\n")


    def __clear(self):
            self.__text.delete(1.0,"end")

    def __hexclear(self):
            self.__hextext.delete(1.0,"end")
            self.__Hextext_bytecomment()
            global g_i_hexheader_counter
            g_i_hexheader_counter=0


    def __GetStrOnOff(self, bitvalue):
            if bitvalue == 0:
                return "Aus"
            else: return "An"

    def __GetStrBetriebsmodus(self, ivalue):
            if ivalue == 1:
                return "Heizen"
            elif  ivalue == 0:
                return "Warmwasser"
            else:
                return "--"

    def __GetStrBetriebsart(self, ivalue):
            if ivalue == 1:
                return "Frost"
            elif ivalue == 2:
                return "Sparen"
            elif ivalue == 3:
                return "Heizen"
            else:
                return "---"

    def __colourconfig(self, obj):
        obj.tag_config("f_bl", foreground="black")
        obj.tag_config("b_ye", background="yellow")
        obj.tag_config("b_bl", background="lightblue")
        obj.tag_config("b_gr", background="lightgreen")
        obj.tag_config("b_rd", background="red")
        obj.tag_config("b_mocca", background="moccasin")
        obj.tag_config("b_gray", background="lightgray")
        obj.tag_config("b_or", background="orange")
        obj.tag_config("u", underline=True)

    def __Hextext_bytecomment(self):
        temptext="BNr"
        for x in range (0,33):
            temptext = temptext+" "+format(x,"02d")
        self.__hextext.insert("end",temptext+'\n',"b_ye")

    def __anzeigesteuerung(self):
        # if newdata available, display them
        if self.__gdata.IsAnyUpdate():
            self.__clear()
            self.__Lokalezeit()
            if self.__current_display=="system":
                self.__System()
            elif self.__current_display==str(self.__gdata.getlongname("HG")): #"heizgeraet"
                self.__Heizgeraet()
            elif self.__current_display==str(self.__gdata.getlongname("HK")): #"heizkreis"
                self.__Heizkreis()
            elif self.__current_display==str(self.__gdata.getlongname("WW")): #"warmwasser"
                self.__Warmwasser()
            elif self.__current_display==str(self.__gdata.getlongname("SO")): #"solar"
                self.__Solar()
            else:
                self.__System()
                
            self.__gdata.UpdateRead()
               

#--- class gui_cworker end ---#

### Runs only for test ###########
if __name__ == "__main__":
    import data
    configurationfilename='./../etc/config/4test/HT3_4dispatcher_test.xml'
    testdata=data.cdata()
    testdata.read_db_config(configurationfilename)
    
    hexdump_window=1
    GUI=gui_cworker(testdata, hexdump_window)
    GUI.run()
    print("must be never reached")
    ############ end main - task ###############

