#! /usr/bin/python3
#
#################################################################
## Copyright (c) 2013 Norbert S. <junky-zs@gmx.de>
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#
#################################################################
# Ver:A  / Datum 21.01.2014
#################################################################

import serial
import ht3_decode, data, db_sqlite
import db_info

class cht3_dispatch(object):
    def __init__(self, port, commondata, database, debug=0):
        try:
            #check at first the parameters
            if not isinstance(port, serial.serialposix.Serial): raise TypeError("port")
            if not isinstance(commondata, data.cdata)  : raise TypeError("commondata")
            if not isinstance(database, db_sqlite.cdb_sqlite): raise TypeError("database")
        except (TypeError) as e:
            print('cht3_dispatch();Error;Parameter:<{0}> has wrong type'.format(e.args[0]))
            raise e

        self.port=port
        self.data=commondata
        self.decode=ht3_decode.cht3_decode(self.data)
        self.database=database
        self.buffer=[0 for x in range(100)]
        self.debug=debug

        try:
            self.__rrdtool_info=db_info.crrdtool_info(database)
        except (OSError, EnvironmentError, TypeError, NameError) as e:
            print('cht3_dispatch();Error;{0}; rrdtool_info init failed'.format(e.args[0]))
            self.__rrdtool_info=None
            raise e
            

    ## check Msg-header and call decode-functions
    def dispatcher(self):
        length=0
        value=[]
        nickname=""
        try:
            firstbyte=ord(self.port.read())
            if firstbyte == 0x88:
                self.buffer[0] = firstbyte
                for x in range (1,4):
                    self.buffer[x] = ord(self.port.read())
                if self.buffer[1] == 0:
                    ## Telegram: Heizgeraet (88001800) ##
                    if (self.buffer[2] == 0x18 and self.buffer[3] == 0):
                        nickname="HG"
                        length=31
                        for x in range (4, length):
                            self.buffer[x] = ord(self.port.read())
                        value=self.decode.HeizgeraetMsg(self.buffer, length)
                        if not value == None:
                            self.database.insert(str(self.data.getlongname(nickname)), value)
                            self.database.commit()
                            if self.debug:
                                print("'{0}':{1}\n".format(nickname, value))
                            
                    ## Telegram: Heizkreis1 (88001900) ##
                    elif (self.buffer[2] == 0x19 and self.buffer[3] == 0):
                        nickname="HK"
                        length=33
                        for x in range (4, length):
                            self.buffer[x] = ord(self.port.read())
                        value=self.decode.HeizkreisMsg(self.buffer, length)
                        if not value == None:
                            self.database.insert(str(self.data.getlongname(nickname)), value)
                            self.database.commit()
                            if self.debug:
                                print("'{0}':{1}\n".format(nickname, value))
                            
                    ## Telegram: Warmwasser (88003400) ##
                    elif (self.buffer[2] == 0x34 and self.buffer[3] == 0):
                        nickname="WW"
                        length=23
                        for x in range (4, length):
                            self.buffer[x] = ord(self.port.read())
                        value=self.decode.WarmwasserMsg(self.buffer, length)
                        if not value == None:
                            self.database.insert(str(self.data.getlongname(nickname)), value)
                            self.database.commit()
                            if self.debug:
                                print("'{0}':{1}\n".format(nickname, value))
                            
                    ## Telegram: Request    (88000700) ##
                    elif (self.buffer[2] == 0x07 and self.buffer[3] == 0):
                        nickname=""
                        length=21
                        for x in range (4, length):
                            self.buffer[x] = ord(self.port.read())
                        self.decode.RequestMsg(self.buffer, length)
                        # nothing to do for database

            ## Telegram: HK2 / Datum ##
            if firstbyte == 0x90:
                self.buffer[0] = firstbyte
                for x in range (1,4):
                    self.buffer[x] = ord(self.port.read())
                if self.buffer[1] == 0:
                    ## Telegram: Heizkreis2 (9000FF00) ##
                    if (self.buffer[2] == 0xff and self.buffer[3] == 0):
                        nickname="HK"
                        length=17
                        for x in range (4, length):
                            self.buffer[x] = ord(self.port.read())
                        value=self.decode.HeizkreisMsg_FW100_200Msg(self.buffer, length)
                        if not value == None:
                            self.database.insert(str(self.data.getlongname(nickname)), value)
                            self.database.commit()
                            if self.debug:
                                print("'{0}':{1}\n".format(nickname, value))
                            
                    ## Telegram: Datum / Uhrzeit (90000600) ##
                    elif (self.buffer[2] == 6 and self.buffer[3] == 0):
                        nickname="DT"
                        length=14
                        for x in range (4, length):
                            self.buffer[x] = ord(self.port.read())
                        value=self.decode.DatumUhrzeitMsg(self.buffer, length)
                        if not value == None:
                            self.database.insert(str(self.data.getlongname(nickname)), value)
                            self.database.commit()
                            if self.debug:
                                print("'{0}':{1}\n".format(nickname, value))

                
            ## Telegram: ISM Solarinfo (B000FF00) ##
            elif firstbyte == 0xb0:
                self.buffer[0] = firstbyte
                for x in range (1,4):
                    self.buffer[x] = ord(self.port.read())
                if (self.buffer[1] == 0 and self.buffer[2] == 0xff and self.buffer[3] == 0):
                    nickname="SO"
                    length=21
                    for x in range (4, length):
                        self.buffer[x] = ord(self.port.read())
                    value=self.decode.SolarMsg(self.buffer, length)
                    if not value == None:
                        self.database.insert(str(self.data.getlongname(nickname)), value)
                        self.database.commit()
                        if self.debug:
                            print("'{0}':{1}\n".format(nickname, value))

            else:                
                # do db_info-tests if enabled
                if  self.__rrdtool_info.isrrdtool_info_active():
                    self.__rrdtool_info.rrdtool_update()
            
        except (LookupError, IndexError, KeyError, TypeError, IOError, UnboundLocalError) as e:
            print('cht3_dispatch.dispatcher();Error;<{0}>'.format(e.args[0]))
            
################################################
if __name__ == "__main__":
    import serial, sys, os
    import data, db_sqlite

##################### configure as required ####
    serialdevice="/dev/ttyUSB0"
#    serialdevice="/dev/ttyUSB1"
###########################
    configurationfilename='./../etc/config/4test/HT3_4dispatcher_test.xml'


    print("----- do some real checks -----")
    print(" used device       :<{0}>".format(serialdevice))
    print(" used configuration:<{0}>".format(configurationfilename))
    print()    
    print("For this test it is required to have:")
    print(" 1. Hardware connected to the above serial-device.")
    print("    If not, change the name in this file and start again.")
    print(" 2. Hardware connected to the Heater HT3-bus")
    print("As result it is:")
    print(" 1. Database created if not available")
    print(" 2. Intercepted data written to stdout")
    print(" 3. Intercepted data written to sqlite database")
    try:
        port = serial.Serial(serialdevice, 9600 )
    except:
        print()
        print("couldn't open requested device: <{0}>".format(serialdevice))
        print()
        sys.exit(1)
        
    print("-- create database")
    db=db_sqlite.cdb_sqlite(configurationfilename)
    db.connect()
    db.createdb_sqlite()
    DB_path_and_name=db.db_sqlite_filename()
    if os.access(DB_path_and_name,os.W_OK and os.R_OK):
        print("Database:'{0}' created and access possible".format(DB_path_and_name))
    else:
        print("Database:'{0}' not available".format(DB_path_and_name))
        sys.exit(1)
    
    testdata=data.cdata()
    testdata.read_db_config(configurationfilename)
    
    debug=1
    HT3=cht3_dispatch(port, testdata, db, debug)
    while True:
        HT3.dispatcher()

    try:
        # must be never reached but for completeness
        db.close()
    except:
        print("!!! Error in ht3_dispatcher occured !!!")
