#! /usr/bin/python3
#
#################################################################
## Copyright (c) 2013 Norbert S. <junky-zs@gmx.de>
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#
#################################################################
# Ver:A  / Datum 21.01.2014
#################################################################

import sys, serial, _thread, sqlite3
import data, ht3_dispatch, gui_worker, db_sqlite

class ht3_cworker(object):
    # setup static data-struct
    __gdata=data.cdata()
    def __init__(self, configurationfilename, serialdevice="/dev/ttyUSB0", hexdump_window=True, gui_active=True):
        try:
            if not (isinstance(hexdump_window,int) or isinstance(hexdump_window,bool)):
                raise TypeError("hexdump_window")
            self.__cfgfilename =str(configurationfilename)
            self.__hexdump_window=bool(hexdump_window)
            self.__gui_active    =bool(gui_active)
            self.__serialdevice  =str(serialdevice)
            self.__port=None
            self.__threadrun=True

        except (TypeError) as e:
            print('ht3_cworker();Error;Parameter:<{0}> has wrong type'.format(e.args[0]))
            raise e
        
    def __del__(self):
        if self.__port != None:
            self.__port.close()

    def run(self):
        try:
            self.__port = serial.Serial(self.__serialdevice, 9600 )
        except:
            print("ht3_cworker();Error;couldn't open requested device:{0}".format(self.__serialdevice))
            quit()

        try:
            # create database-sqlite if required
            db=db_sqlite.cdb_sqlite(self.__cfgfilename)
            if not db.is_sqlite_db_available():
###                if self.__gui_active:
###                    # disply information, creating database if not available
###                    import tkinter.messagebox
###                    response=tkinter.messagebox.askyesno("SQlite-db not available","Creating ?:yes/no")
###                    if response:
###                        print("creating the database")
###                    else:
###                        print("terminating, no further run")
###                        quit()
###                else:
                print("Wait a bit, database: sqlite will be created");
            else:
                print("database already available")
                
            db.connect()
            db.createdb_sqlite()
            db.close()
            
            # read configurationfile and setup default data
            ht3_cworker.__gdata.read_db_config(self.__cfgfilename)

            # start thread for dispatching
            _thread.start_new_thread(self.__DispatchThread, (0,))

            if self.__gui_active:
                # start GUI endless until 'Ende' is pressed
                GUI=gui_worker.gui_cworker(ht3_cworker.__gdata, self.__hexdump_window)
                self.__threadrun=GUI.run()

        except (sqlite3.OperationalError, ValueError) as e:
            print("ht3_cworker();Error; {0}".format(e))
            quit()
            
    def __DispatchThread(self, parameter):
            debug=0
            # get db-instance
            database=db_sqlite.cdb_sqlite(self.__cfgfilename)
            database.connect()
            message=ht3_dispatch.cht3_dispatch(self.__port, ht3_cworker.__gdata, database, debug)
            while self.__threadrun:
                message.dispatcher()
            #close db at the end of thread
            database.close()
        

#--- class ht3_cworker end ---#

### Runs only for test ###########
if __name__ == "__main__":
    configurationfilename='./../etc/config/4test/HT3_4dispatcher_test.xml'
    ##### activate the valid devicename for the HT3-Port
    #
    # deviceport="/dev/ttyAMA0"
    deviceport="/dev/ttyUSB0"
    # deviceport="/dev/ttyUSB1"
    #####

    HT3_Worker=ht3_cworker(configurationfilename, deviceport)
    HT3_Worker.run()

    

